@@ -429,7 +429,7 @@ class Form(TabContent):
             delimiter = ';'
         fileno, fname = tempfile.mkstemp(
             '.csv', common.slugify(export['name']) + '_')
-        with open(fname, 'w') as fp:
+        with open(fname, 'w', newline='') as fp:
             writer = csv.writer(fp, delimiter=delimiter)
             for row, path in zip_longest(data, paths or []):
                 indent = len(path) - 1 if path else 0
